@@ -12,6 +12,6 @@ SPVM::IO::Socket::INET - Socket ipv4 implementation
 
 =head1 DESCRIPTION
 
-L<SPVM::IO::Socket::INET> provides socket utilities.
+C<IO::Socket::INET> provides socket utilities.
 
 B<SPVM::IO::Socket::INET is now development release. The changes without warnings are offten quit will be done.>
